asr.test.acceptance.test\_borncharges
=====================================

.. automodule:: asr.test.acceptance.test_borncharges

   
   
   .. rubric:: Functions

   
   .. autofunction:: test_gpaw_berry_get_berry_phases_integration
   
   

   
   
   

   
   
   